@@ -22,35 +22,33 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "documentviewcontainer.h"
 
 // Local
+#include "gwenview_lib_debug.h"
 #include <lib/graphicswidgetfloater.h>
 #include <lib/gvdebug.h>
 #include <lib/gwenviewconfig.h>
-#include "gwenview_lib_debug.h"
 
 // KF
 
 // Qt
-#include <QOpenGLWidget>
 #include <QGraphicsScene>
+#include <QOpenGLWidget>
 #include <QPropertyAnimation>
 #include <QTimer>
 #include <QtMath>
 
 namespace Gwenview
 {
-
 using DocumentViewSet = QSet<DocumentView *>;
 using SetupForUrl = QHash<QUrl, DocumentView::Setup>;
 
-struct DocumentViewContainerPrivate
-{
-    DocumentViewContainer* q;
-    QGraphicsScene* mScene;
+struct DocumentViewContainerPrivate {
+    DocumentViewContainer *q;
+    QGraphicsScene *mScene;
     SetupForUrl mSetupForUrl;
     DocumentViewSet mViews;
     DocumentViewSet mAddedViews;
     DocumentViewSet mRemovedViews;
-    QTimer* mLayoutUpdateTimer;
+    QTimer *mLayoutUpdateTimer;
 
     void scheduleLayoutUpdate()
     {
@@ -61,7 +59,7 @@ struct DocumentViewContainerPrivate
      * Remove view from set, move it to mRemovedViews so that it is later
      * deleted.
      */
-    bool removeFromSet(DocumentView* view, DocumentViewSet* set)
+    bool removeFromSet(DocumentView *view, DocumentViewSet *set)
     {
         DocumentViewSet::Iterator it = set->find(view);
         if (it == set->end()) {
@@ -73,22 +71,22 @@ struct DocumentViewContainerPrivate
         return true;
     }
 
-    void resetSet(DocumentViewSet* set)
+    void resetSet(DocumentViewSet *set)
     {
         qDeleteAll(*set);
         set->clear();
     }
 };
 
-DocumentViewContainer::DocumentViewContainer(QWidget* parent)
-: QGraphicsView(parent)
-, d(new DocumentViewContainerPrivate)
+DocumentViewContainer::DocumentViewContainer(QWidget *parent)
+    : QGraphicsView(parent)
+    , d(new DocumentViewContainerPrivate)
 {
     d->q = this;
     d->mScene = new QGraphicsScene(this);
 #ifndef QT_NO_OPENGL
     if (GwenviewConfig::animationMethod() == DocumentView::GLAnimation) {
-        auto* glWidget = new QOpenGLWidget;
+        auto *glWidget = new QOpenGLWidget;
         setViewport(glWidget);
     }
 #endif
@@ -112,9 +110,9 @@ DocumentViewContainer::~DocumentViewContainer()
     delete d;
 }
 
-DocumentView* DocumentViewContainer::createView()
+DocumentView *DocumentViewContainer::createView()
 {
-    auto* view = new DocumentView(d->mScene);
+    auto *view = new DocumentView(d->mScene);
     view->setPalette(palette());
     d->mAddedViews << view;
     view->show();
@@ -123,7 +121,7 @@ DocumentView* DocumentViewContainer::createView()
     return view;
 }
 
-void DocumentViewContainer::deleteView(DocumentView* view)
+void DocumentViewContainer::deleteView(DocumentView *view)
 {
     if (d->removeFromSet(view, &d->mViews)) {
         return;
@@ -131,12 +129,12 @@ void DocumentViewContainer::deleteView(DocumentView* view)
     d->removeFromSet(view, &d->mAddedViews);
 }
 
-DocumentView::Setup DocumentViewContainer::savedSetup(const QUrl& url) const
+DocumentView::Setup DocumentViewContainer::savedSetup(const QUrl &url) const
 {
     return d->mSetupForUrl.value(url);
 }
 
-void DocumentViewContainer::updateSetup(DocumentView* view)
+void DocumentViewContainer::updateSetup(DocumentView *view)
 {
     d->mSetupForUrl[view->url()] = view->setup();
 }
@@ -148,20 +146,20 @@ void DocumentViewContainer::reset()
     d->resetSet(&d->mRemovedViews);
 }
 
-void DocumentViewContainer::showEvent(QShowEvent* event)
+void DocumentViewContainer::showEvent(QShowEvent *event)
 {
     QWidget::showEvent(event);
     updateLayout();
 }
 
-void DocumentViewContainer::resizeEvent(QResizeEvent* event)
+void DocumentViewContainer::resizeEvent(QResizeEvent *event)
 {
     QWidget::resizeEvent(event);
     d->mScene->setSceneRect(rect());
     updateLayout();
 }
 
-static bool viewLessThan(DocumentView* v1, DocumentView* v2)
+static bool viewLessThan(DocumentView *v1, DocumentView *v2)
 {
     return v1->sortKey() < v2->sortKey();
 }
@@ -171,18 +169,18 @@ void DocumentViewContainer::updateLayout()
     // Stop update timer: this is useful if updateLayout() is called directly
     // and not through scheduleLayoutUpdate()
     d->mLayoutUpdateTimer->stop();
-    QList<DocumentView*> views = (d->mViews | d->mAddedViews).values();
+    QList<DocumentView *> views = (d->mViews | d->mAddedViews).values();
     std::sort(views.begin(), views.end(), viewLessThan);
 
     bool animated = GwenviewConfig::animationMethod() != DocumentView::NoAnimation;
     bool crossFade = d->mAddedViews.count() == 1 && d->mRemovedViews.count() == 1;
 
     if (animated && crossFade) {
-        DocumentView* oldView = *d->mRemovedViews.begin();
-        DocumentView* newView = *d->mAddedViews.begin();
+        DocumentView *oldView = *d->mRemovedViews.begin();
+        DocumentView *newView = *d->mAddedViews.begin();
 
         newView->setGeometry(rect());
-        QPropertyAnimation* anim = newView->fadeIn();
+        QPropertyAnimation *anim = newView->fadeIn();
 
         oldView->setZValue(-1);
         connect(anim, &QPropertyAnimation::finished, oldView, &DocumentView::hideAndDeleteLater);
@@ -226,7 +224,7 @@ void DocumentViewContainer::updateLayout()
         int col = 0;
         int row = 0;
 
-        for (DocumentView * view : qAsConst(views)) {
+        for (DocumentView *view : qAsConst(views)) {
             QRect rect;
             rect.setLeft(col * viewWidth);
             rect.setTop(row * viewHeight);
@@ -265,12 +263,12 @@ void DocumentViewContainer::updateLayout()
 
     // Handle removed views
     if (animated) {
-        for (DocumentView* view : qAsConst(d->mRemovedViews)) {
+        for (DocumentView *view : qAsConst(d->mRemovedViews)) {
             view->fadeOut();
             QTimer::singleShot(DocumentView::AnimDuration, view, &QObject::deleteLater);
         }
     } else {
-        for (DocumentView* view : qAsConst(d->mRemovedViews)) {
+        for (DocumentView *view : qAsConst(d->mRemovedViews)) {
             view->deleteLater();
         }
         QMetaObject::invokeMethod(this, &DocumentViewContainer::pretendFadeInFinished, Qt::QueuedConnection);
@@ -283,12 +281,12 @@ void DocumentViewContainer::pretendFadeInFinished()
     // Animations are disabled. Pretend all fade ins are finished so that added
     // views are moved to mViews, will modify d->mAddedViews
     const auto currentViews = d->mAddedViews;
-    for (DocumentView* view : currentViews) {
+    for (DocumentView *view : currentViews) {
         slotFadeInFinished(view);
     }
 }
 
-void DocumentViewContainer::slotFadeInFinished(DocumentView* view)
+void DocumentViewContainer::slotFadeInFinished(DocumentView *view)
 {
     if (!d->mAddedViews.contains(view)) {
         // This can happen if user goes to next image then quickly goes to the
@@ -302,7 +300,7 @@ void DocumentViewContainer::slotFadeInFinished(DocumentView* view)
 void DocumentViewContainer::slotConfigChanged()
 {
 #ifndef QT_NO_OPENGL
-    bool currentlyGL = qobject_cast<QOpenGLWidget*>(viewport());
+    bool currentlyGL = qobject_cast<QOpenGLWidget *>(viewport());
     bool wantGL = GwenviewConfig::animationMethod() == DocumentView::GLAnimation;
     if (currentlyGL != wantGL) {
         setViewport(wantGL ? new QOpenGLWidget() : new QWidget());
@@ -310,9 +308,9 @@ void DocumentViewContainer::slotConfigChanged()
 #endif
 }
 
-void DocumentViewContainer::showMessageWidget(QGraphicsWidget* widget, Qt::Alignment align)
+void DocumentViewContainer::showMessageWidget(QGraphicsWidget *widget, Qt::Alignment align)
 {
-    DocumentView* view = nullptr;
+    DocumentView *view = nullptr;
     if (d->mViews.isEmpty()) {
         GV_RETURN_IF_FAIL(!d->mAddedViews.isEmpty());
         view = *d->mAddedViews.begin();
@@ -322,17 +320,17 @@ void DocumentViewContainer::showMessageWidget(QGraphicsWidget* widget, Qt::Align
     GV_RETURN_IF_FAIL(view);
 
     widget->setParentItem(view);
-    auto* floater = new GraphicsWidgetFloater(view);
+    auto *floater = new GraphicsWidgetFloater(view);
     floater->setChildWidget(widget);
     floater->setAlignment(align);
     widget->show();
     widget->setZValue(1);
 }
 
-void DocumentViewContainer::applyPalette(const QPalette& palette)
+void DocumentViewContainer::applyPalette(const QPalette &palette)
 {
     setPalette(palette);
-    for (DocumentView* view : d->mViews | d->mAddedViews) {
+    for (DocumentView *view : d->mViews | d->mAddedViews) {
         view->setPalette(palette);
     }
 }
