@@ -20,8 +20,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "slideshow.h"
 
 // STL
-#include <ctime>
 #include <algorithm>
+#include <ctime>
 
 // Qt
 #include <QAction>
@@ -32,12 +32,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // Local
 #include "gwenview_lib_debug.h"
-#include <lib/gvdebug.h>
 #include <gwenviewconfig.h>
+#include <lib/gvdebug.h>
 
 namespace Gwenview
 {
-
 #undef ENABLE_LOG
 #undef LOG
 //#define ENABLE_LOG
@@ -50,7 +49,7 @@ namespace Gwenview
 enum State {
     Paused,
     Started,
-    WaitForEndOfUrl
+    WaitForEndOfUrl,
 };
 
 /**
@@ -61,7 +60,7 @@ class RandomNumberGenerator
 {
 public:
     RandomNumberGenerator()
-    : mSeed(time(nullptr))
+        : mSeed(time(nullptr))
     {
     }
 
@@ -74,9 +73,8 @@ private:
     unsigned int mSeed;
 };
 
-struct SlideShowPrivate
-{
-    QTimer* mTimer;
+struct SlideShowPrivate {
+    QTimer *mTimer;
     State mState;
     QVector<QUrl> mUrls;
     QVector<QUrl> mShuffledUrls;
@@ -84,8 +82,8 @@ struct SlideShowPrivate
     QUrl mCurrentUrl;
     QUrl mLastShuffledUrl;
 
-    QAction* mLoopAction;
-    QAction* mRandomAction;
+    QAction *mLoopAction;
+    QAction *mRandomAction;
 
     QUrl findNextUrl()
     {
@@ -171,9 +169,9 @@ struct SlideShowPrivate
     }
 };
 
-SlideShow::SlideShow(QObject* parent)
-: QObject(parent)
-, d(new SlideShowPrivate)
+SlideShow::SlideShow(QObject *parent)
+    : QObject(parent)
+    , d(new SlideShowPrivate)
 {
     d->mState = Paused;
 
@@ -201,17 +199,17 @@ SlideShow::~SlideShow()
     delete d;
 }
 
-QAction* SlideShow::loopAction() const
+QAction *SlideShow::loopAction() const
 {
     return d->mLoopAction;
 }
 
-QAction* SlideShow::randomAction() const
+QAction *SlideShow::randomAction() const
 {
     return d->mRandomAction;
 }
 
-void SlideShow::start(const QList<QUrl>& urls)
+void SlideShow::start(const QList<QUrl> &urls)
 {
     d->mUrls.resize(urls.size());
     std::copy(urls.begin(), urls.end(), d->mUrls.begin());
@@ -229,14 +227,14 @@ void SlideShow::start(const QList<QUrl>& urls)
     d->updateTimerInterval();
     d->mTimer->setSingleShot(false);
     d->doStart();
-    emit stateChanged(true);
+    Q_EMIT stateChanged(true);
 }
 
 void SlideShow::setInterval(int intervalInSeconds)
 {
     GwenviewConfig::setInterval(double(intervalInSeconds));
     d->updateTimerInterval();
-    emit intervalChanged(intervalInSeconds);
+    Q_EMIT intervalChanged(intervalInSeconds);
 }
 
 int SlideShow::interval() const
@@ -267,7 +265,7 @@ void SlideShow::pause()
     LOG("Stopping timer");
     d->mTimer->stop();
     d->mState = Paused;
-    emit stateChanged(false);
+    Q_EMIT stateChanged(false);
 }
 
 void SlideShow::resumeAndGoToNextUrl()
@@ -287,7 +285,7 @@ void SlideShow::goToNextUrl()
         pause();
         return;
     }
-    emit goToUrl(url);
+    Q_EMIT goToUrl(url);
 }
 
 void SlideShow::setCurrentUrl(const QUrl &url)
