@@ -29,18 +29,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 namespace Gwenview
 {
-
 namespace ThumbnailGroup
 {
 enum Enum {
     Normal,
     Large,
-    Large2x
+    Large2x,
 };
 
 inline int pixelSize(const Enum value)
 {
-    switch(value) {
+    switch (value) {
     case Normal:
         return 128;
     case Large:
